<?php  

    /**********************************************************************
    this is a sample of the code you should use on your production plugin
    this part check and validate the license key
    /**********************************************************************/
	
	if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

    // register settings
    function wprsdt_my_settings_init() {
        // register the settins for the plugin here   (you might want to give it more unique names)
		register_setting( 'wprsdt_plugin_options_group', 'wprsdt_options', 'wprsdt_sanitize_wprsdt_validate_options' );
    }
    add_action('admin_init', 'wprsdt_my_settings_init');
	add_action('init','wprsdt_check_active');

    // register the plugin admin page
    // this is called if the plugin is valid and ok
    function wprsdt_my_add_plugin_admin_page(){
		
		add_submenu_page('wprs',
							'<i class="fa fa-cube"></i> '.__('Data Tables', 'wprs'), 
							'<i class="fa fa-cube"></i> '.__('Data Tables', 'wprs'), 
							'manage_options',
							'wprs-datatables',
							'wprsdt_my_plugin_admin_page'
						);
    }


	// Sanitize and validate input. Accepts an array, return a sanitized array.
	function wprsdt_sanitize_wprsdt_validate_options($input) {
		// do stuff with $options to check they are ok
        if(isset($_POST['reset'])){
			delete_option('wprsdt_settings_license_option');
		}
		
		// 
		$old = get_option( 'wprsdt_license_key' );
		if( $old && $old != $input ) {
			delete_option( 'wprsdt_license_status' ); // new license has been entered, so must reactivate
		}
		return $input;
	}

			
	
    /**
    * call back function that renders your plugins settings page
    * 
    */
    function wprsdt_my_plugin_admin_page(){
		
		$options = get_option('wprsdt_options');
		
        echo '<div class="wrap">';
		echo '<h2>'.WPRSDT_PLUGIN_NAME.' Settings <span style="font-size:10px;">Ver '.WPRSDT_VER.'</span></h2>';
		echo '<form method="post" action="options.php">';
		settings_fields('wprsdt_plugin_options_group');
		settings_errors();
		require_once ('settings_datatables.php');		// load table settings
		echo '<div style="clear:both;"></div>';
		echo '</div>';
		echo '<div style="clear:both;"></div>';
        echo '</form>';
    }
	
    // this function should definitely be obfuscated or encrypted so hacker cannot bypass it
    // we call this function at the init action so it can set up all the proper actions and filters that the plugin would use.
    // we only do the actions required for validation if the plugin is not yet valid
    function wprsdt_check_active(){      

            // plugin is ok
            // do the actions and filters
			add_action( 'admin_menu',	'wprsdt_my_add_plugin_admin_page', 99); // the function to show the plugin settings page
    }

	
// ------------------------------------------------------------------------------
// CALLBACK FUNCTION FOR: register_activation_hook(__FILE__, 'wprsdt_add_defaults')
// ------------------------------------------------------------------------------
// THIS FUNCTION RUNS WHEN THE PLUGIN IS ACTIVATED. IF THERE ARE NO THEME OPTIONS
// CURRENTLY SET, OR THE USER HAS SELECTED THE CHECKBOX TO RESET OPTIONS TO THEIR
// DEFAULTS THEN THE OPTIONS ARE SET/RESET.
//
// OTHERWISE, THE PLUGIN OPTIONS REMAIN UNCHANGED.
// ------------------------------------------------------------------------------

	// Define default option settings
	function wprsdt_add_defaults() {
		$tmp = get_option('wprsdt_options');
    	if(($tmp['wprsdt_chk_default_options_db']=='1')||(!is_array($tmp))) {
			delete_option('wprsdt_options'); // so we don't have to reset all the 'off' checkboxes too! ( I don't think this is needed but leave for now)
			$arr = array(	
							// add default setting below...
							
							// general settings
							
							// other settings
							"wprsdt_chk_default_options_db" => ""
			);
			update_option('wprsdt_options', $arr);
		}
	}


add_action('admin_init', 'wprsdt_activate_license');
/*
	Activate a license key
	*/
function wprsdt_activate_license() {

	// listen for our activate button to be clicked
	if( isset( $_POST['wprsdt_license_activate'] ) ) {

		// run a quick security check 
	 	if( ! check_admin_referer( 'wprsdt_nonce', 'wprsdt_nonce' ) ) 	
			return; // get out if we didn't click the Activate button

		$options = get_option('wprsdt_options');
		
		// Retrieve license key from the DB
		$license = trim( $options['wprsdt_license_key']);
			

		// data to send in our API request
		$api_params = array( 
			'edd_action'=> 'activate_license', 
			'license' 	=> $license, 
			'item_name' => urlencode( WPRSDT_PLUGIN_DOWNLOAD_NAME ), // the name of our product in EDD
			'url'       => home_url()
		);
		
		// Call the custom API.
		$response = wp_remote_get( add_query_arg( $api_params, WPRICHSNIPPETS_WEBSITE_URL ), array( 'timeout' => 15, 'sslverify' => false ) );
		
		// make sure the response came back okay
		if ( is_wp_error( $response ) )
			return false;

		// decode the license data
		$license_data = json_decode( wp_remote_retrieve_body( $response ) );
		
		// $license_data->license will be either "valid" or "invalid"

		update_option( 'wprsdt_license_status', $license_data->license );

	}
}



add_action('admin_init', 'wprsdt_deactivate_license');
/* 
	Deactivate the license key.
	*/
function wprsdt_deactivate_license() {

	// listen for our activate button to be clicked
	if( isset( $_POST['wprsdt_license_deactivate'] ) ) {

		// run a quick security check 
	 	if( ! check_admin_referer( 'wprsdt_nonce', 'wprsdt_nonce' ) ) 	
			return; // get out if we didn't click the Activate button

		$options = get_option('wprsdt_options');
		
		// Retrieve license key from the DB
		$license = trim( $options['wprsdt_license_key']);
			

		// data to send in our API request
		$api_params = array( 
			'edd_action'=> 'deactivate_license', 
			'license' 	=> $license, 
			'item_name' => urlencode( WPRSDT_PLUGIN_DOWNLOAD_NAME ), // the name of our product in EDD
			'url'       => home_url()
		);
		
		// Call the custom API.
		$response = wp_remote_get( add_query_arg( $api_params, WPRICHSNIPPETS_WEBSITE_URL ), array( 'timeout' => 15, 'sslverify' => false ) );

		// make sure the response came back okay
		if ( is_wp_error( $response ) )
			return false;

		// decode the license data
		$license_data = json_decode( wp_remote_retrieve_body( $response ) );
		
		// $license_data->license will be either "deactivated" or "failed"
		if( $license_data->license == 'deactivated' )
			delete_option( 'wprsdt_license_status' );

	}
}

