<?php
	/*
	Plugin Name: WPRS DataTables
    Plugin URI: http://authorhreview.com
    Description: Shortcode to display table of entries based on DataTables. An add-on for the WPRichSnippets plugin.
    Version: 1.1
    Author: Hesham Zebida
    Author URI: http://zebida.com
    Last Version update : 20 June 2015
	Text Domain: wprs-datatables
    */
	
	if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
	
	// plugin version, used to add version for scripts and styles
	define( 'WPRSDT_VER', '1.1' );
	define( 'WPRSDT_PLUGIN_NAME', 'WPRS DataTables' );
	define( 'WPRSDT_PLUGIN_DOWNLOAD_NAME', 'DataTables' );
	if ( ! defined( 'WPRICHSNIPPETS_WEBSITE_URL' ) ) define( 'WPRICHSNIPPETS_WEBSITE_URL', 'http://wprichsnippets.com' );

	// define plugin URLs, for fast enqueuing scripts and styles
	if ( ! defined( 'WPRSDT_URL' ) )
		define( 'WPRSDT_URL', plugin_dir_url( __FILE__ ) );
	define( 'WPRSDT_INC_URL', trailingslashit( WPRSDT_URL . 'inc' ) );
	define( 'WPRSDT_JS_URL',	trailingslashit( WPRSDT_URL . 'js' ) );
	define( 'WPRSDT_CSS_URL', trailingslashit( WPRSDT_URL . 'css' ) );
			
	// set up plugin actions
    add_action( 'admin_init', 'wprsdt_requires_wordpress_version' );			// check WP version 3.9+


	// ------------------------------------------------------------------------
	// REQUIRES
	// ------------------------------------------------------------------------
	require_once ('inc/admin/settings.php');								// load admin settings
	require_once ('inc/admin/updater.php');									// load updater
	// shortcode
	require_once ('inc/shortcode_datatables.php');							// load shortcode

	
	
	// ------------------------------------------------------------------------
	// REQUIRE MINIMUM VERSION OF WORDPRESS:                                               
	// ------------------------------------------------------------------------
	function wprsdt_requires_wordpress_version() {
		global $wp_version;
		$plugin = plugin_basename( __FILE__ );
		$plugin_data = get_plugin_data( __FILE__, false );

		if ( version_compare($wp_version, "3.9", "<" ) ) {
			if( is_plugin_active($plugin) ) {
				deactivate_plugins( $plugin );
				wp_die( "'".$plugin_data['Name']."' requires WordPress 3.0 or higher, and has been deactivated! Please upgrade WordPress and try again.<br /><br />Back to <a href='".admin_url()."'>WordPress admin</a>." );
			}
		}
	}
	
	// check if WP Reviews is active
	function wprsdt_detect_wprs()  {
		$xplugin = 'wp-rich-snippets/wp-rich-snippets.php';
		$plugin = plugin_basename( __FILE__ );
		if ( !is_plugin_active($xplugin) ) {
			// display notice if plugin isn't active
			add_action('admin_notices', 'wprsdt_my_admin_notice');
			// deactivate
			deactivate_plugins( $plugin );
		}
	}
	add_action( 'admin_init', 'wprsdt_detect_wprs' );
	
	// the notice
	function wprsdt_my_admin_notice(){
		echo '<div class="update-nag"><p>The <a href="http://authorhreview.com/plugins/wp-rich-snippets/" title="WPRichSnippets Plugin" target="_blank" >WPRichSnippets</a> plugin is required. Plugin has been deactivated!</p></div>';
	}


	// Localization
	add_action('init', 'wprsdt_localization_init');
	/*
		Load the WPRS Ranking Table textdomain for internationalization.
		*/
	function wprsdt_localization_init() {
	
		$path = dirname(plugin_basename( __FILE__ )) . '/inc/languages/';
		$loaded = load_plugin_textdomain('wprs-datatables', false, $path);
		if(isset($_GET['page'])) {
			if ($_GET['page'] == basename(__FILE__) && !$loaded) {          
				echo '<div class="error">WPRS DataTables Localization: ' . __('Could not load the localization file: ' . $path, 'wprs-datatables') . '</div>';
				return;
			}
		}
	
	}
	
	
// Add-on updates
add_action( 'admin_init', 'wprsdt_sl_updater', 0 );
/**
 * Check for add-ons updates
 *
 * @uses wprsdt_sl_updater()
 *
 * @since 1.1
 */
function wprsdt_sl_updater() {
	
	// get options
	$options = get_option('wprsdt_options');
		
	// Retrieve license key from the DB
	$license = trim( $options['wprsdt_license_key']);
	

	// Setup the updater
	$edd_updater = new WPRS_SL_Plugin_Updater( WPRICHSNIPPETS_WEBSITE_URL, __FILE__, array( 
			'version' 	=> WPRSDT_VER, 						// current version number
			'license' 	=> $license, 						// license key (used get_option above to retrieve from DB)
			'item_name' => WPRSDT_PLUGIN_DOWNLOAD_NAME, 	// name of this add-on
			'author' 	=> 'Hesham Zebida'  				// author of this add-on
		)
	);

}

